<?php
// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;


/**
 * Main BuddyDrive Component Class
 *
 * Inspired by BuddyPress skeleton component
 */
class BuddyDrive_Component extends BP_Component {

	/**
	 * Constructor method
	 *
	 *
	 * @package BuddyDrive
	 * @since 1.0
	 */
	
	function __construct() {
		global $blog_id;

		parent::start(
			buddydrive_get_slug(),
			buddydrive_get_name(),
			buddydrive_get_includes_dir()
		);

	 	$this->includes();
		
		buddypress()->active_components[$this->id] = '1';

		/**
		 * Register the BuddyDrive custom post types
		 */
		if( $blog_id == BP_ROOT_BLOG ) {
			add_action( 'init', array( &$this, 'register_post_types' ), 9 );
			
			$this->register_upload_dir();
		}
		
		// register the embed handler
		wp_embed_register_handler( 'buddydrive', '#'.buddydrive_get_root_url().'\/(.+?)\/(.+?)\/#i', 'wp_embed_handler_buddydrive' );
	}

	/**
	 * BuddyDrive needed files
	 *
	 * @package BuddyDrive
	 * @since 1.0
	 *
	 * @uses bp_is_active() to check if group component is active
	 */
	function includes() {

		// Files to include
		$includes = array(
			'buddydrive-item-filters.php',
			'buddydrive-item-actions.php',
			'buddydrive-item-screens.php',
			'buddydrive-item-classes.php',
			'buddydrive-item-functions.php',
			'buddydrive-item-template.php',
			'buddydrive-item-ajax.php',
			'buddydrive-item-s3.php'
		);
		
		if( bp_is_active( 'groups' ) )
			$includes[] = 'buddydrive-group-class.php';
		

		parent::includes( $includes );

	}

	/**
	 * Set up BuddyDrive globals
	 *
	 * @package BuddyDrive
	 * @since 1.0
	 *
	 * @global obj $bp BuddyPress's global object
	 * @uses buddypress() to get the instance data
	 * @uses buddydrive_get_slug() to get BuddyDrive root slug
	 */
	function setup_globals() {
		$bp = buddypress();

		// Set up the $globals array to be passed along to parent::setup_globals()
		$globals = array(
			'slug'                  => buddydrive_get_slug(),
			'root_slug'             => isset( $bp->pages->{$this->id}->slug ) ? $bp->pages->{$this->id}->slug : buddydrive_get_slug(),
			'has_directory'         => true,
			'notification_callback' => 'buddydrive_format_notifications',
			'search_string'         => __( 'Search files...', 'buddydrive' )
		);

		// Let BP_Component::setup_globals() do its work.
		parent::setup_globals( $globals );
		
	}

	/**
	 * Set up buddydrive navigation.
	 * 
	 * @uses buddypress() to get the instance data
	 * @uses buddydrive_get_name() to get BuddyDrive name
	 * @uses buddydrive_get_slug() to get BuddyDrive slug
	 * @uses bp_displayed_user_id() to get the displayed user id
	 * @uses bp_displayed_user_domain() to get displayed user profile link
	 * @uses bp_loggedin_user_domain() to get current user profile link
	 * @uses bp_is_active() to check if the friends component is active
	 */
	function setup_nav() {
		$bp =  buddypress();
		
		$main_nav = array(
			'name' 		      => buddydrive_get_name(),
			'slug' 		      => buddydrive_get_slug(),
			'position' 	      => 80,
			'screen_function'     => 'buddydrive_user_files',
			'default_subnav_slug' => 'files'
		);
		$displayed_user_id = bp_displayed_user_id();
		$user_domain = ( !empty( $displayed_user_id ) ) ? bp_displayed_user_domain() : bp_loggedin_user_domain();

		$buddydrive_link = trailingslashit( $user_domain . buddydrive_get_slug() );

		// Add a few subnav items under the main Example tab
		$sub_nav[] = array(
			'name'            =>  __( 'BuddyDrive Files', 'buddydrive' ),
			'slug'            => 'files',
			'parent_url'      => $buddydrive_link,
			'parent_slug'     => $this->slug,
			'screen_function' => 'buddydrive_user_files',
			'position'        => 10,
		);

		// Add the subnav items to the friends nav item
		if( bp_is_active('friends') && bp_displayed_user_id() == bp_loggedin_user_id() ) {
			$sub_nav[] = array(
				'name'            =>  __( 'Shared by Friends', 'buddydrive' ),
				'slug'            => 'friends',
				'parent_url'      => $buddydrive_link,
				'parent_slug'     => $this->slug,
				'screen_function' => 'buddydrive_friends_files',
				'position'        => 20
			);
		}
		

		parent::setup_nav( $main_nav, $sub_nav );
		
	}
	
	/**
	 * Builds the user's navigation in WP Admin Bar
	 *
	 * @uses buddydrive_get_slug() to get BuddyDrive slug
	 * @uses is_user_logged_in() to check if the user is logged in
	 * @uses bp_loggedin_user_domain() to get current user's profile link
	 * @uses buddydrive_get_name() to get BuddyDrive plugin name
	 * @uses bp_is_active() to check for the friends component
	 */
	function setup_admin_bar() {

		// Prevent debug notices
		$wp_admin_nav = array();
		$buddydrive_slug = buddydrive_get_slug();

		// Menus for logged in user
		if ( is_user_logged_in() ) {

			// Setup the logged in user variables
			$buddydrive_link = trailingslashit( bp_loggedin_user_domain() . $buddydrive_slug );

			// Add main BuddyDrive menu
			$wp_admin_nav[] = array(
				'parent' => 'my-account-buddypress',
				'id'     => 'my-account-' . $buddydrive_slug,
				'title'  => buddydrive_get_name(),
				'href'   => trailingslashit( $buddydrive_link )
			);
			
			// Add BuddyDrive submenu
			$wp_admin_nav[] = array(
				'parent' => 'my-account-' . $buddydrive_slug,
				'id'     => 'my-account-' . $buddydrive_slug .'-files',
				'title'  => __( 'BuddyDrive Files', 'buddydrive' ),
				'href'   => trailingslashit( $buddydrive_link )
			);
			
			if( bp_is_active('friends') ) {
				// Add shared by friends BuddyDrive submenu
				$wp_admin_nav[] = array(
					'parent' => 'my-account-' . $buddydrive_slug,
					'id'     => 'my-account-' . $buddydrive_slug .'-friends',
					'title'  => __( 'Shared by Friends', 'buddydrive' ),
					'href'   => trailingslashit( $buddydrive_link . 'friends' )
				);
			}

		}

		parent::setup_admin_bar( $wp_admin_nav );
	}

	/**
	 * registering BuddyDrive custom post types
	 * 
	 * @uses buddydrive_get_folder_post_type() to get the BuddyFolder post type
 	 * @uses buddydrive_get_file_post_type() to get the BuddyFile post type
 	 * @uses register_post_type() to register the post type
	 */
	function register_post_types() {
		
		// Set up some labels for the post type
		$labels_file = array(
			'name'	             => __( 'BuddyFiles', 'buddydrive' ),
			'singular'           => __( 'BuddyFile', 'buddydrive' ),
			'menu_name'          => __( 'BuddyDrive Files', 'buddydrive' ),
			'all_items'          => __( 'All BuddyFiles', 'buddydrive' ),
			'singular_name'      => __( 'BuddyFile', 'buddydrive' ),
			'add_new'            => __( 'Add New BuddyFile', 'buddydrive' ),
			'add_new_item'       => __( 'Add New BuddyFile', 'buddydrive' ),
			'edit_item'          => __( 'Edit BuddyFile', 'buddydrive' ),
			'new_item'           => __( 'New BuddyFile', 'buddydrive' ),
			'view_item'          => __( 'View BuddyFile', 'buddydrive' ),
			'search_items'       => __( 'Search BuddyFiles', 'buddydrive' ),
			'not_found'          => __( 'No BuddyFiles Found', 'buddydrive' ),
			'not_found_in_trash' => __( 'No BuddyFiles Found in Trash', 'buddydrive' )
		);
		
		$args_file = array(
			'label'	            => __( 'BuddyFile', 'buddydrive' ),
			'labels'            => $labels_file,
			'public'            => false,
			'rewrite'           => false,
			'show_ui'           => false,
			'show_in_admin_bar' => false,
			'supports'          => array( 'title', 'editor', 'author' )
		);

		// Register the post type for files.
		register_post_type( buddydrive_get_file_post_type(), $args_file );


		$labels_folder = array(
			'name'	             => __( 'BuddyFolders', 'buddydrive' ),
			'singular'           => __( 'BuddyFolder', 'buddydrive' ),
			'menu_name'          => __( 'BuddyDrive Folders', 'buddydrive' ),
			'all_items'          => __( 'All BuddyFolders', 'buddydrive' ),
			'singular_name'      => __( 'BuddyFolder', 'buddydrive' ),
			'add_new'            => __( 'Add New BuddyFolder', 'buddydrive' ),
			'add_new_item'       => __( 'Add New BuddyFolder', 'buddydrive' ),
			'edit_item'          => __( 'Edit BuddyFolder', 'buddydrive' ),
			'new_item'           => __( 'New BuddyFolder', 'buddydrive' ),
			'view_item'          => __( 'View BuddyFolder', 'buddydrive' ),
			'search_items'       => __( 'Search BuddyFolders', 'buddydrive' ),
			'not_found'          => __( 'No BuddyFolders Found', 'buddydrive' ),
			'not_found_in_trash' => __( 'No BuddyFolders Found in Trash', 'buddydrive' )
		);
		
		$args_folder = array(
			'label'	            => __( 'BuddyFolder', 'buddydrive' ),
			'labels'            => $labels_folder,
			'public'            => false,
			'rewrite'           => false,
			'show_ui'           => false,
			'show_in_admin_bar' => false,
			'supports'          => array( 'title', 'editor', 'author' )
		);

		// Register the post type for files.
		register_post_type( buddydrive_get_folder_post_type(), $args_folder );

		parent::register_post_types();
	}
	
	
	/**
	 * register the BuddyDrive upload data in instance
	 *
	 * @uses buddydrive_get_upload_data() to get the specific BuddyDrive upload datas
	 */
	function register_upload_dir() {
		$upload_data = buddydrive_get_upload_data();
		
		if( is_array( $upload_data ) ) {
			buddydrive()->upload_dir = $upload_data['dir'];
			buddydrive()->upload_url = $upload_data['url'];
		}
		
	}

}

/**
 * Finally Loads the component into the $bp global
 *
 * @uses buddypress()
 */
function buddydrive_load_component() {
	buddypress()->buddydrive = new BuddyDrive_Component;
}
add_action( 'bp_loaded', 'buddydrive_load_component' );
?>